@@ -15,7 +15,6 @@ from .functions import (
     create_database,
     create_mock_engine,
     database_exists,
-    defer_except,
     dependent_objects,
     drop_database,
     escape_like,
@@ -35,6 +34,7 @@ from .functions import (
     has_unique_index,
     identity,
     is_loaded,
+    json_sql,
     merge_references,
     mock_engine,
     naturally_equivalent,
@@ -87,7 +87,7 @@ from .types import (
 from .models import Timestamp
 
 
-__version__ = '0.29.1'
+__version__ = '0.29.2'
 
 
 __all__ = (
@@ -102,7 +102,6 @@ __all__ = (
     create_database,
     create_mock_engine,
     database_exists,
-    defer_except,
     dependent_objects,
     drop_database,
     escape_like,
